% Calcula a média vetorial do vento
% Considerando a convenção meteorológica de direção do vento 
% (ex: vento de norte com wdir=0o, vento de leste com wdir=90o)
%
% Input:
% ws: vetor com velocidade do vento em cada instante
% wd: vetor com direção do vento em graus em cada instante
%
% Output:
% wsmed: média vetorial da velocidade do vento
% wdmed: média vetorial da direção do vento em graus
% umed: média da componente u da velocidade do vento
% vmed: média da componente v da velocidade do vento
%
%function [stat,statorder] = fmedia_qualquer_coisa2(data_mqc,first,last,delta,tol)
function [wsmed,wdmed,umed,vmed] = fmeanwind(ws,wd)
wd=wd*pi/180; % deg to rad
umed=nanmean(-ws.*sin(wd)); 
vmed=nanmean(-ws.*cos(wd)); 
wsmed=sqrt(umed^2 + vmed^2);
wdmed=mod(-90-atan2(vmed,umed)*180/pi,360); % deg